@@ -628,9 +628,9 @@ module Bio
 
     def test_seqclass_when_seqclass_set
       alignment = Alignment.new
-      alignment.seqclass = Fixnum
+      alignment.seqclass = Integer
       alignment << "this doesn't really make sense"
-      assert_equal(Fixnum, alignment.seqclass)
+      assert_equal(Integer, alignment.seqclass)
     end
 
     # Alignment#gap_char
